

/*
   orxonox - the future of 3D-vertical-scrollers

   Copyright (C) 2004 orx

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   ### File Specific
   main-programmer: Patrick Boenzli
   co-programmer:
*/


#include "test_bullet.h"

#include "model.h"
#include "vector.h"
#include "garbage_collector.h"
#include "fast_factory.h"

#include "obb_tree.h"

using namespace std;

CREATE_FAST_FACTORY(TestBullet, CL_TEST_BULLET);

/**
 *  standard constructor
*/
TestBullet::TestBullet () : Projectile()
{
  this->setClassID(CL_TEST_BULLET, "TestBullet");

  float modelSize = .3;
  this->loadModelWithScale("models/projectiles/orx-rocket.obj", .3);

  this->energyMin = 1;
  this->energyMax = 10;
  this->remove();
  this->lifeSpan = 5;
}


/**
 *  standard deconstructor
*/
TestBullet::~TestBullet ()
{
  /*
     do not delete the test projectModel, since it is pnode
     and will be cleaned out by world
  */
  //delete this->projectileModel;
}

void TestBullet::collidesWith(WorldEntity* entity, const Vector& location)
{
  this->destroy();
}

/**
 *  signal tick, time dependent things will be handled here
 * @param time since last tick
*/
void TestBullet::tick (float time)
{
  //Vector v = *this->flightDirection * ( this->speed * time * 1000 + 0.1);
  Vector v = this->velocity * (time);
  this->shiftCoor(v);

  this->lifeCycle += time/this->lifeSpan;
  if( this->lifeCycle >= 1)
    {
      PRINTF(5)("FINALIZE==========================\n");
      PRINTF(5)("current life cycle is: %f\n", this->lifeCycle);
      PRINTF(5)("FINALIZE===========================\n");
//      this->finalize();
      GarbageCollector::getInstance()->collect(this);
      this->lifeCycle = 0.0; //! @todo should not be here
    }
}

/**
 *  the function gets called, when the projectile is destroyed
*/
void TestBullet::destroy ()
{


}


void TestBullet::draw ()
{
  glMatrixMode(GL_MODELVIEW);
  glPushMatrix();

  float matrix[4][4];
  glTranslatef (this->getAbsCoor ().x, this->getAbsCoor ().y, this->getAbsCoor ().z);
  this->getAbsDir().matrix (matrix);
  glMultMatrixf((float*)matrix);
  glScalef(2.0, 2.0, 2.0);
  this->model->draw();

  glPopMatrix();
}

